==> com.liferay.site.cms.site.initializer-1.0.6-sources.jar: com/liferay/site/cms/site/initializer/internal/constants/CMSSiteInitializerFDSNames.java <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cms.site.initializer.internal.constants;

/**
 * @author Jürgen Kappler
 */
public class CMSSiteInitializerFDSNames {

	public static final String ALL_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-allSection";

	public static final String ALL_SPACES_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-allSpacesSection";

	public static final String CATEGORIES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-categories";

	public static final String CATEGORIZATION_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME +
			"-categorizationSection";

	public static final String CATEGORIZATION_TAGS =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME +
			"-categorizationTags";

	public static final String CONTENTS_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-contentsSection";

	public static final String FILES_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-filesSection";

	public static final String STRUCTURE_USAGES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-structureUsages";

	public static final String STRUCTURES_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-structuresSection";

	public static final String VOCABULARIES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-vocabularies";

}

==> com.liferay.site.cms.site.initializer-1.0.7-sources.jar: com/liferay/site/cms/site/initializer/internal/constants/CMSSiteInitializerFDSNames.java <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cms.site.initializer.internal.constants;

/**
 * @author Jürgen Kappler
 */
public class CMSSiteInitializerFDSNames {

	public static final String ALL_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-allSection";

	public static final String ALL_SPACES_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-allSpacesSection";

	public static final String CATEGORIES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-categories";

	public static final String CATEGORIZATION_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME +
			"-categorizationSection";

	public static final String CATEGORIZATION_TAGS =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME +
			"-categorizationTags";

	public static final String CATEGORY_USAGES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-categoryUsages";

	public static final String CONTENTS_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-contentsSection";

	public static final String FILES_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-filesSection";

	public static final String STRUCTURE_USAGES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-structureUsages";

	public static final String STRUCTURES_SECTION =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-structuresSection";

	public static final String TAG_USAGES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-tagUsages";

	public static final String VOCABULARIES =
		CMSSiteInitializerConstants.BUNDLE_SYMBOLIC_NAME + "-vocabularies";

}
